.. _ydoc directive_1:

``directive_1``
===============

This is a description of Directive 1

Single-valued parameter:

  * ``directive_1_2``: This is a description of Directive 1.2



Container-like parameter:

.. toctree::
   :maxdepth: 1

   directive_1/directive_1_1


----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.